---
feature_story: FS_61_67_08_53
feature_title: non-searchable arg types
feature_status: TBD
---

Some arg types are non-searchable: there is no way to index their arg types as `data_envelope`-s.

For example, if there is a function to download a file,
remote file path is such arg (arbitrary, not part of indexed data).

TODO: Figure out how to specify these arg types.
